@@ -1,4 +1,5 @@
 use reqwest::header::InvalidHeaderValue;
+use rustyline::error::ReadlineError;
 use thiserror::Error;
 
 pub type Result<T> = std::result::Result<T, Error>;
@@ -8,6 +9,9 @@ pub enum Error {
     #[error("Unable to download {0}")]
     Download(String),
 
+    #[error("`mpv` or `vlc` required for streaming")]
+    MediaPlayer,
+
     #[error("Unable get data from source\nFrom: {0}")]
     Network(#[from] reqwest::Error),
 
@@ -24,17 +28,17 @@ pub enum Error {
     Quit,
 
     #[error("No match found")]
-    Tui,
+    Choices,
 
-    #[error("vlc is required for streaming")]
-    Vlc,
+    #[error("Invalid input")]
+    UserInput(ReadlineError),
 
     // Generic errors
     #[error("{0}")]
     Custom(String),
 
     #[error("{0}")]
-    IoError(#[from] std::io::Error),
+    Io(#[from] std::io::Error),
 
     // File system errors
     #[error("Unable to open file")]
