@@ -8,7 +8,7 @@ macro_rules! bail {
 /// Fill url placeholder with episode digit
 macro_rules! gen_url {
     ($str:expr, $num:expr) => {
-        $str.replace(crate::utils::PLACEHOLDER, &zfill!($num))
+        $str.replace("_{}", &zfill!($num))
     };
 }
 
@@ -19,7 +19,7 @@ macro_rules! unroll {
             Ok(item) => item,
             Err(err) => {
                 if (!matches!(err, Error::Quit)) {
-                    bunt::eprintln!("{$red}{}{/$}", err)
+                    eprintln!("{}", err.red())
                 }
                 continue;
             }
@@ -34,7 +34,7 @@ macro_rules! ok {
             Ok(item) => item,
             Err(err) => {
                 if (!matches!(err, Error::Quit)) {
-                    bunt::eprintln!("{$red}{}{/$}", err);
+                    eprintln!("{}", err.red());
                 }
                 return;
             }
